-
¿Qué es Mariabackup?
-
Copia de seguridad y restauración de MariaDB con Mariabackup
-
Copia de seguridad y restauración de MariaDB con mysqldump
-
Copia de seguridad y recuperación de MariaDB con una solución de copia de seguridad de bases de datos

MariaDB es un popular sistema de gestión de bases de datos relacionales (SGBDR) de código abierto, diseñado para ser un reemplazo directo de MySQL. Fue creado por los desarrolladores originales de MySQL tras surgir preocupaciones sobre su adquisición por parte de Oracle Corporation.
MariaDB tiene una alta compatibilidad con MySQL y presenta la misma paridad binaria de bibliotecas, además de coincidir exactamente con las API y los comandos de MySQL. Esto facilita la migración de bases de datos desde MySQL a MariaDB.
Si está utilizando MariaDB, es fundamental que sepa cómo realizar copias de seguridad de MariaDB y cómo restaurarlas. En este artículo, aprenderá a realizar copias de seguridad y restaurar MariaDB mediante Mariabackup y otros dos métodos. A continuación, podría preguntarse: ¿qué es Mariabackup?
¿Qué es Mariabackup?
Mariabackup, una bifurcación de Percona XtraBackup, es una herramienta de código abierto creada por MariaDB que permite realizar copias de seguridad en línea de tablas InnoDB, MyRocks, Aria y MyISAM en formato físico.
Opciones:
| --aplicar-registro | Prepara una copia de seguridad actual para la recuperación del servidor MariaDB. |
| --aplicar-solo-el-registro | Realizar únicamente la fase de aplicación del registro de rehacer. |
| --backup | Copia de seguridad de MariaDB. |
| --información-del-binlog | Especifica la forma de recuperar las coordenadas del registro binario desde el servidor. |
| --cerrar-archivos | Determina si se cierran o no los identificadores de archivo. |
| --compress | Define la compresión del archivo de copia de seguridad. |
| --compress-chunk-size | Especifica el tamaño del búfer de trabajo para los hilos de compresión. |
| --compress-threads | Especifica el número de hilos de compresión. |
| --copiar-de-vuelta | Restaura la copia de seguridad en el directorio de datos. |
| --bases de datos | Selecciona las bases de datos y tablas que deseas respaldar. |
Nota: Visite la página de opciones de Mariabackup para obtener más información.
Características:
Configura una réplica a partir de una copia de seguridad.
Utiliza herramientas de cifrado y compresión.
Restaura tablas y particiones individuales.
Admite el método SST con el clúster Glaera.
Admite copias de seguridad y restauraciones completas, parciales e incrementales.
Realiza copias de seguridad y restauraciones de tablas mediante el cifrado de datos en reposo, el motor de almacenamiento MyRocks y la compresión de páginas InnoDB.
Minimiza los bloqueos durante la copia de seguridad y ofrece un soporte óptimo para copias de seguridad en todos los motores de almacenamiento de MariaDB Enterprise Backup.
Ventajas:
Código abierto y gratuito de usar.
Proporciona un alto nivel de coherencia e integridad de los datos.
Fácil de configurar y usar, con documentación clara y una interfaz intuitiva.
Diseñado específicamente para MariaDB, está optimizado para ese sistema de gestión de bases de datos en particular.
Desventajas:
Solo admite operaciones de copia de seguridad y restauración para MariaDB.
No admite el cifrado basado en herramientas de copia de seguridad ni la opción de compactación.
Requiere algunos conocimientos sobre interfaces de línea de comandos y procedimientos de copia de seguridad.
No admite la compresión ni el cifrado de datos en reposo para la funcionalidad de copia de seguridad completa.
No admite copias de seguridad parciales de los datos de MyRocks y las copias de seguridad incrementales almacenarán una copia completa.
Puede no ser adecuado para bases de datos muy grandes o para operaciones de copia de seguridad que deban realizarse con frecuencia, ya que puede consumir una cantidad significativa de recursos del sistema.
Tenga cuidado de no incluir errores tipográficos ni utilizar opciones de versiones más recientes de Mariabackup, ya que el software ignora las opciones desconocidas de la línea de comandos sin mostrar un mensaje de error.
Instalar Mariabackup
En Linux:
Instálelo con un gestor de paquetes y ejecute como root:
curl -LsS https://r.mariadb.com/downloads/mariadb_repo_setup | sudo bash
Instale con yum/dnf para RHEL, CentOS, Fedora y otras distribuciones Linux similares:
sudo yum install MariaDB-backup
Instale con apt-get en Debian, Ubuntu y otras distribuciones Linux similares:
sudo apt-get install mariadb-backup
Instalación con el gestor de paquetes zipper para SLES, openSUSE y otras distribuciones Linux similares:
sudo zypper install MariaDB-backup
En Windows:
1. Instale el paquete MSI de MariaDB.
2. Haga clic en mariadb-<major>.<minor>.<patch>.msi.
3. Haga clic en Siguiente en la página de bienvenida y acepte el acuerdo de licencia, luego haga clic en Siguiente.
4. En la página Configuración personalizada, haga clic en Utilidades de copia de seguridad para instalarlas.
5. Siga el asistente.
Copia de seguridad y restauración de MariaDB con Mariabackup
Realice una copia de seguridad de todo el servidor de bases de datos:
$ mariabackup --backup --target-dir=/var/mariadb/backup/ --usuario=mariabackup --contraseña=mypassword
Realice una copia de seguridad incremental (primero cree una copia de seguridad completa):
$ mariabackup --backup --target-dir=/var/mariadb/inc1/ --incremental-basedir=/var/mariadb/backup/ --usuario=mariabackup --contraseña=mypassword
Prepare copias de seguridad consistentes para la recuperación:
$ mariabackup --prepare --directorio-destino=/var/mariadb/backup/
Restaurar la base de datos completa:
a. Detenga el proceso del servidor y asegúrese de que el directorio de datos esté vacío.
b. Ejecute –copy-back para conservar los archivos de copia de seguridad originales o –move-back para mover los datos al directorio de datos, con lo que se perderán los archivos originales.
$ mariabackup --copy-back --target-dir=/var/mariadb/backup/
c. Inicie el proceso del servidor MariaDB.
Restaure los cambios en la primera copia de seguridad incremental y repita el paso para cada una de las restantes con MariaDB 10.2:
a. Prepare la copia de seguridad completa base.
$ mariabackup --prepare --target-dir=/var/mariadb/backup --incremental-dir=/var/mariadb/inc1
b. Sincronice la base con los cambios.
$ mariabackup --prepare --target-dir=/var/mariadb/backup --incremental-dir=/var/mariadb/inc1
c. Detenga el proceso del servidor y asegúrese de que el directorio de datos esté vacío.
d. Ejecute –copy-back para conservar los archivos de copia de seguridad originales o –move-back para mover los datos al directorio de datos, con lo que se perderán los archivos originales.
$ mariabackup --copy-back --target-dir=/var/mariadb/backup/
Restaurar copia de seguridad incremental con MariaDB hasta la versión 10.1:
a. Prepare la copia de seguridad completa base.
$ mariabackup --prepare --apply-log-only --target-dir=/var/mariadb/backup
b. Aplicar los incrementos a la base:
$ mariabackup --prepare --apply-log-only --target-dir=/var/mariadb/backup --incremental-dir=/var/mariadb/inc1
c. Detenga el proceso del servidor y asegúrese de que el directorio de datos esté vacío.
d. Ejecute –copy-back para conservar los archivos de copia de seguridad originales o –move-back para mover los datos al directorio datadir, con lo que se perderán los archivos originales.
$ mariabackup --copy-back --target-dir=/var/mariadb/backup/
Copia de seguridad y restauración de MariaDB con mysqldump
Mysqldump es una herramienta integrada de copia de seguridad de MariaDB que permite exportar una o varias bases de datos para su respaldo o traslado en formatos CSV, otros formatos de texto delimitado o XML, y también puede utilizarse para realizar copias de seguridad y restaurar MySQL.
Exportar todas las bases de datos de MariaDB:
mysqldump -u xx -p -x -A > /data/backup/dbs.sql
Volcar varias bases de datos y todas las bases de datos:
shell> mysqldump --databases db_name1 [db_name2 ...] > my_databases.sql shell> mysqldump --all-databases > all_databases.sql
Realizar una copia de seguridad de toda la base de datos:
shell> mysqldump db_name > backup-file.sql
Copia de seguridad de una sola base de datos:
mysqldump --user=xx --password --lock-tables --databases db1 > /data/backup/db1.sql
Copia de seguridad de una tabla:
mysqldump --user=xx --password --lock-tables db1 table1 > /data/backup/db1_table1.sql
Restaurar una copia de seguridad:
mysql -u root -p < backup-file.sql
Copia de seguridad y recuperación de MariaDB con una solución de copia de seguridad de bases de datos
De cualquier manera, los procesos de copia de seguridad y recuperación de MariaDB distan mucho de ser intuitivos y fáciles de usar para un principiante. Pruebe Vinchin Backup & Recovery, compatible con 12 plataformas de virtualización, como VMware, Hyper-V, Xen, RHEV/oVirt, etc., 2 servidores físicos, NAS y 6 bases de datos, incluidas Oracle DB, MySQL, SQL Server, PostgreSQL, Postgres Pro y MariaDB.

Puede automatizar la copia de seguridad de la base de datos con horarios personalizados y elegir, con un solo clic, entre copias de seguridad completas, diferenciales, incrementales y de registro (varía según la base de datos).
Puede habilitar la desduplicación y la compresión de datos para reducir el tamaño total de las copias de seguridad y activar el cifrado de datos con el estándar AES-256 para garantizar la seguridad.
Restaure MariaDB en la base de datos original o en una nueva ubicación y prepare una copia de seguridad externa en una ubicación remota.
Descargue la versión de prueba gratuita de 60 días de la nueva versión 7.0 ahora:
Proceso sencillo de copia de seguridad de MariaDB:
1. Vaya a Copia de seguridad física > Copia de seguridad de base de datos > Copia de seguridad, y seleccione el agente de copia de seguridad de base de datos instalado y la fuente de copia de seguridad.
2. Seleccione el nodo de copia de seguridad y el almacenamiento en dicho nodo para la tarea.
3. Especifique las estrategias de copia de seguridad según sea necesario.

4. Confirme y envíe.
Proceso sencillo de recuperación de MariaDB:
1. Vaya a Copia de seguridad física > Copia de seguridad de la base de datos > Restaurar y seleccione el recurso de recuperación desde las copias de seguridad de la base de datos.
2. Seleccione la instancia de destino.
3. Restaurar en el destino original o en uno nuevo y especificar las estrategias de restauración.

4. Confirme y envíe.
Conclusión
Puede realizar copias de seguridad y restauraciones de MariaDB con Mariabackup y Mysqldump, pero estas herramientas carecen de una interfaz gráfica intuitiva y de las diversas opciones de copia de seguridad que ofrece Vinchin Backup & Recovery, una solución profesional de copia de seguridad de bases de datos. La herramienta automatiza la copia de seguridad y recuperación de datos, además de proporcionar medidas y tecnologías de protección antimalware sin complicaciones para proteger sus datos de MariaDB de forma integral.
Compartir en: